#!/usr/bin/env python3

import os
import pytest # pylint: disable=unused-import
import socket

import mmpm.mmpm
import mmpm.core
import mmpm.utils
import mmpm.consts
import mmpm.color
import mmpm.models

from logging import Logger
from mmpm_test import consts as test_consts
from mmpm_test.models import MMPMTestLogger

# handles any pre-test setup required
import mmpm_test.pre_test_setup # pylint: disable=unused-import

log: Logger = MMPMTestLogger().logger # type: ignore

MagicMirrorPackage: mmpm.models.MagicMirrorPackage = mmpm.models.MagicMirrorPackage
get_env = mmpm.utils.get_env

def test_internet_connection():
    log.info("Testing basic status of internet connection")
    address: str = "1.1.1.1"
    assert socket.create_connection((address, 80)) and socket.create_connection((address, 443))


def test_module_file_exists(caplog):
    assert os.path.exists(mmpm.consts.MMPM_CLI_LOG_FILE)


def test_module_dir_exists():
    assert os.path.exists(test_consts.MAGICMIRROR_MODULES_DIR)


def test_magic_mirror_installation_found():
    assert os.path.exists(test_consts.MAGICMIRROR_ROOT)


def test_retrieve_packages():
    assert len(mmpm.core.load_packages()) > 0

def test_search_packages_with_valid_query():
    assert mmpm.core.search_packages(mmpm.core.load_packages(), "face")

def test_install_package():
    for pkg in test_consts.VALID_PACKAGES:
        assert mmpm.core.install_package(pkg)

import mmpm_test.post_test_setup # pylint: disable=unused-import



#!/usr/bin/env python3

import json
import mmpm.consts
import pathlib
import shutil

from logging import Logger
from mmpm_test import consts as test_consts
from mmpm_test.models import MMPMTestLogger

log: Logger = MMPMTestLogger().logger # type: ignore

log.info(f"Setting MMPM test environment with MMPM_MAGICMIRROR_ROOT as {test_consts.MAGICMIRROR_ROOT}")

ORIGINAL_ENV = {}

with open(mmpm.consts.MMPM_ENV_FILE, "r") as env:
    try:
        ORIGINAL_ENV = json.load(env)
    except json.JSONDecodeError as error:
        log.error(str(error))

with open(mmpm.consts.MMPM_ENV_FILE, "w") as env:
    json.dump(test_consts.MMPM_TEST_ENV, env, indent=2)

for required_dir in test_consts.REQUIRED_DIRS:
    shutil.rmtree(required_dir, ignore_errors=True)
    pathlib.Path(required_dir).mkdir(parents=True, exist_ok=True)

for required_file in test_consts.REQUIRED_FILES:
    pathlib.Path(required_file).touch(exist_ok=True)



#!/usr/bin/env python3
import os
import mmpm.consts

from mmpm.models import MagicMirrorPackage
from typing import List
from socket import gethostname, gethostbyname

MMPM_TEST_ROOT: str = os.path.join("/", "tmp", "MMPM_TEST")
MMPM_CONFIG_DIR: str = os.path.normpath(os.path.join(MMPM_TEST_ROOT, '.config', 'mmpm'))

MAGICMIRROR_ROOT: str = os.path.join(MMPM_TEST_ROOT, "MagicMirror")
MAGICMIRROR_MODULES_DIR: str = os.path.join(MAGICMIRROR_ROOT, "modules")

MMPM_MODULE_DIR: str = os.path.join(MAGICMIRROR_MODULES_DIR, "mmpm")
MMPM_LOG_DIR: str = os.path.join(MMPM_CONFIG_DIR, "log")
MMPM_CLI_LOG_FILE: str = os.path.join(MMPM_LOG_DIR, "mmpm-cli-interface.log")

MMPM_TEST_ENV: dict = {
    mmpm.consts.MMPM_MAGICMIRROR_ROOT_ENV: MAGICMIRROR_ROOT,
    mmpm.consts.MMPM_MAGICMIRROR_URI_ENV: f'http://{gethostbyname(gethostname())}:8080',
    mmpm.consts.MMPM_MAGICMIRROR_PM2_PROCESS_NAME_ENV: '',
    mmpm.consts.MMPM_MAGICMIRROR_DOCKER_COMPOSE_FILE_ENV: '',
    mmpm.consts.MMPM_IS_DOCKER_IMAGE_ENV: False,
}

REQUIRED_DIRS: List[str] = [
    MMPM_LOG_DIR
]

REQUIRED_FILES: List[str] = [
    MMPM_CLI_LOG_FILE
]

VALID_PACKAGES: List[MagicMirrorPackage] = [
    MagicMirrorPackage(
        title="MMM-COVID19",
        author="bibaldo",
        repository="https://github.com/bibaldo/MMM-COVID19",
        description="Keep track of Corona Virus (COVID-19) cases via rapidapi API"
    ),
    MagicMirrorPackage(
        title="MagicMirror-Module-Template",
        author="MichMich",
        repository="https://github.com/roramirez/MagicMirror-Module-Template",
        description="Module to help developers to start building their own modules for the MagicMirror."
    )
]

INVALID_PACKAGES: List[MagicMirrorPackage] = [
    MagicMirrorPackage(
        title="ThisPackageNameBetterNotExistOtherwiseItWouldExtremelyWeird",
        author="bsdfasadfasdfa",
        repository="this_isnt_a_valid_url",
        description="This description does not matter at all"
    ),
    MagicMirrorPackage(
        title="ThisPackageNameBetterNotExistOtherwiseItWouldExtremelyWeirdAlso",
        author="asdfasdfasdfasdfas",
        repository="this_also_isnt_a_valid_url",
        description="This description does not matter at all"
    )
]



#!/usr/bin/env python3

import mmpm.consts
import json
from mmpm_test import pre_test_setup

with open(mmpm.consts.MMPM_ENV_FILE, "w") as env:
    json.dump(pre_test_setup.ORIGINAL_ENV, env, indent=2)



#!/usr/bin/env python3
import os
import logging
import logging.handlers
import mmpm_test.consts

class MMPMTestLogger():
    """
    Object used for logging while MMPM tests are executing.  Log files can be
    found in "/tmp/MMPM_TEST/log/mmpm-cli-interface.log"
    """

    def __init__(self):
        self.log_file: str = mmpm_test.consts.MMPM_CLI_LOG_FILE

        if not os.path.exists(mmpm_test.consts.MMPM_LOG_DIR):
            os.system(f"mkdir -p {mmpm_test.consts.MMPM_LOG_DIR}")

        os.system(f"touch {mmpm_test.consts.MMPM_CLI_LOG_FILE}")

        self.log_format: str = "%(asctime)s.%(msecs)03d %(levelname)s %(module)s - %(funcName)s: %(message)s"
        logging.basicConfig(filename=self.log_file, format=self.log_format)
        logger: logging.Logger = logging.getLogger()
        logger.setLevel(logging.INFO)

        self.handler = logging.handlers.RotatingFileHandler(
            self.log_file,
            mode="a",
            maxBytes=1024*1024,
            backupCount=2,
            encoding=None,
            delay=0
        )

        logger.addHandler(self.handler)
        self.logger = logger
